@@ -51,6 +51,8 @@ from wbcore.models import WBModel
 from wbcore.models.fields import YearField
 from wbcore.utils.models import ComplexToStringMixin
 
+from wbhuman_resources.signals import add_employee_activity_to_daily_brief
+
 from .absence import AbsenceRequest, AbsenceRequestPeriods
 from .calendars import DayOff, DayOffCalendar, DefaultDailyPeriod
 from .preferences import (
@@ -235,11 +237,6 @@ class EmployeeHumanResource(ComplexToStringMixin, WBModel):
                 title="Vacation Notification",
                 help_text="Notifies you when there are Vacation days that you still have to take",
             ),
-            create_notification_type(
-                code="wbhuman_resources.employeehumanresource.birthday",
-                title="Birthday Notification",
-                help_text="Notifies you when today one of your colleagues is celebrating their birthday",
-            ),
         ]
 
     def unassign_position_groups(self):
@@ -830,8 +827,11 @@ class BalanceHourlyAllowance(models.Model):
             models.Index(fields=["balance", "period_index"]),
         ]
 
+    def __str__(self) -> str:
+        return f"{self.balance} - {self.period_index} Period Index: {self.hourly_allowance}"
 
-class EmployeeYearBalance(ComplexToStringMixin, models.Model):
+
+class EmployeeYearBalance(ComplexToStringMixin):
     employee = models.ForeignKey(
         EmployeeHumanResource,
         related_name="balances",
@@ -935,7 +935,7 @@ class EmployeeYearBalance(ComplexToStringMixin, models.Model):
         return "wbhuman_resources:employeeyearbalancerepresentation-list"
 
 
-class EmployeeWeeklyOffPeriods(ComplexToStringMixin, models.Model):
+class EmployeeWeeklyOffPeriods(ComplexToStringMixin):
     employee = models.ForeignKey(
         "wbhuman_resources.EmployeeHumanResource",
         related_name="default_periods_relationships",
@@ -1210,3 +1210,32 @@ def deactivate_profile_as_task(requester_id: int, employee_id: int, substitute_i
         body=gettext("The following actions have been done: \n{messages}").format(messages=messages),
         user=requester,
     )
+
+
+@receiver(add_employee_activity_to_daily_brief, sender="directory.Person")
+def daily_birthday(sender, instance: Person, val_date: date, **kwargs) -> tuple[str, str] | None:
+    """
+    Cron task supposed to be ran every day. Check and notify employee about a colleague's birthday.
+    """
+
+    # If daily brief is a monday, we get the birthday that happen during the weekend as well
+    if val_date.weekday() == 0:
+        sunday = val_date - timedelta(days=1)
+        saturday = val_date - timedelta(days=2)
+        conditions = (
+            (Q(profile__birthday__day=val_date.day) & Q(profile__birthday__month=val_date.month))
+            | (Q(profile__birthday__day=sunday.day) & Q(profile__birthday__month=sunday.month))
+            | (Q(profile__birthday__day=saturday.day) & Q(profile__birthday__month=saturday.month))
+        )
+    else:
+        conditions = Q(profile__birthday__day=val_date.day) & Q(profile__birthday__month=val_date.month)
+    birthday_firstnames = list(
+        EmployeeHumanResource.active_internal_employees.filter(conditions)
+        .exclude(profile=instance)
+        .values_list("profile__first_name", flat=True)
+    )
+    if birthday_firstnames:
+        birthday_firstnames_humanized = f"{', '.join(birthday_firstnames[:-1])} and {birthday_firstnames[-1]}"
+        return "Today Birthdays", _("Today is {}'s birthday, Which them a happy birthday!").format(
+            birthday_firstnames_humanized
+        )
