@@ -6,8 +6,11 @@ from django.utils import timezone
 
 
 def get_number_of_hours_between_dates(
-    d1, d2, list_employee_dayoffs, list_public_holidays=False, hours_range=range(0, 23), granularity=12
+    d1, d2, list_employee_dayoffs, list_public_holidays=False, hours_range=None, granularity=12
 ):
+    if hours_range is None:
+        hours_range = range(0, 23)
+
     def convert_days_from_hours(hours, granularity, hours_per_day):
         return int(hours / granularity) * granularity / hours_per_day
 
