@@ -1,4 +1,3 @@
-import wbcore.serializers as wb_serializers
 from django.contrib.messages import info, warning
 from django.db.models import Case, CharField, F, Q, Sum, Value, When
 from django.db.models.functions import Concat, Extract
@@ -56,11 +55,6 @@ from wbhuman_resources.viewsets.titles import (
 )
 
 from ..models.absence import can_validate_or_deny_request
-from ..serializers.absence import (
-    CurrentUserDefaultPeriodDateTimeRange,
-    get_lower_time_choices,
-    get_upper_time_choices,
-)
 from .mixins import EmployeeViewMixin
 
 
@@ -114,20 +108,6 @@ class AbsenceRequestModelViewSet(EmployeeViewMixin, viewsets.ModelViewSet):
             return can_validate_or_deny_request(obj, self.request.user)
         return False
 
-    def get_serializer_class(self):
-        if employee := getattr(self.request.user.profile, "human_resources", None):
-
-            class Serializer(AbsenceRequestModelSerializer):
-                period = wb_serializers.DateTimeRangeField(
-                    default_timezone=employee.calendar.timezone,
-                    default=CurrentUserDefaultPeriodDateTimeRange(),
-                    lower_time_choices=get_lower_time_choices,
-                    upper_time_choices=get_upper_time_choices,
-                )
-
-            return Serializer
-        return AbsenceRequestModelSerializer
-
     def add_messages(
         self,
         request,
